summaryrefslogtreecommitdiffstats
path: root/kviewshell/pageSizeWidget.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kviewshell/pageSizeWidget.cpp')
-rw-r--r--kviewshell/pageSizeWidget.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kviewshell/pageSizeWidget.cpp b/kviewshell/pageSizeWidget.cpp
index 5446fd53..9f2503d2 100644
--- a/kviewshell/pageSizeWidget.cpp
+++ b/kviewshell/pageSizeWidget.cpp
@@ -21,10 +21,10 @@
// Constructs a pageSizeWidget_base which is a child of 'tqparent', with
// the name 'name' and widget flags set to 'f'.
-pageSizeWidget::pageSizeWidget( TQWidget* tqparent, const char* name, WFlags fl )
- : pageSizeWidget_base( tqparent, name, fl )
+pageSizeWidget::pageSizeWidget( TQWidget* parent, const char* name, WFlags fl )
+ : pageSizeWidget_base( parent, name, fl )
{
connect(&chosenSize, TQT_SIGNAL(sizeChanged(const SimplePageSize&)), previewer, TQT_SLOT(setSize(const SimplePageSize&)));
@@ -21,10 +21,10 @@
-// Constructs a pageSizeWidget_base which is a child of 'tqparent', with
+// Constructs a pageSizeWidget_base which is a child of 'parent', with
// the name 'name' and widget flags set to 'f'.